<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Верификујте отисак прста</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Успешна верификација</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Неуспешна верификација, имате још %n покушај</numerusform><numerusform>Неуспешна верификација, имате још %n покушаја</numerusform><numerusform>Неуспешна верификација, имате још %n покушаја</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Неуспешна верификација, имате још један покушај</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Отисак прста је закључан, употребите лозинку</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Покушајте поново за %n минут</numerusform><numerusform>Покушајте поново за %n минута</numerusform><numerusform>Покушајте поново за %n минута</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Успешна верификација</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Неуспешна верификација, имате још %n покушај</numerusform><numerusform>Неуспешна верификација, имате још %n покушаја</numerusform><numerusform>Неуспешна верификација, имате још %n покушаја</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Неуспешна верификација, имате још један покушај</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Погрешна лозинка</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Покушајте поново за %n минут</numerusform><numerusform>Покушајте поново за %n минута</numerusform><numerusform>Покушајте поново за %n минута</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Покушајте поново за 1 минут</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Покушајте поново за %n минут</numerusform><numerusform>Покушајте поново за %n минута</numerusform><numerusform>Покушајте поново за %n минута</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Успешна верификација</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Неуспешна верификација, имате још %n покушај</numerusform><numerusform>Неуспешна верификација, имате још %n покушаја</numerusform><numerusform>Неуспешна верификација, имате још %n покушаја</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Неуспешна верификација, имате још један покушај</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Погрешан ПИН</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Потребан је У-Кључ</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Унесите ПИН</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Покушајте поново за %n минут</numerusform><numerusform>Покушајте поново за %n минута</numerusform><numerusform>Покушајте поново за %n минута</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthenticationModule</name>
    <message>
        <source>Verification successful</source>
        <translation>Успешна верификација</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Неуспешна верификација, имате још %n покушај</numerusform><numerusform>Неуспешна верификација, имате још %n покушаја</numerusform><numerusform>Неуспешна верификација, имате још %n покушаја</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Неуспешна верификација, имате још један покушај</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Погрешна лозинка</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Погрешан ПИН</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Потребан је У-Кључ</translation>
    </message>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Верификујте отисак прста</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Лозинка</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Унесите ПИН</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Отисак прста је закључан, употребите лозинку</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Покушајте поново за 1 минут</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Покушајте поново за %n минут</numerusform><numerusform>Покушајте поново за %n минута</numerusform><numerusform>Покушајте поново за %n минута</numerusform></translation>
    </message>
</context>
<context>
    <name>ContentWidget</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Програми спречавају искључивање. Принудно искључивање може изазвати губитак података.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Да затворите програм, кликните на Откажи, затим затворите.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Програми спречавају поновно покретање. Принудно поновно покретање може изазвати губитак података.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Програми спречавају обуставу. Принудно обустављање може изазвати губитак података.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Програми спречавају хибернацију. Принудна хибернација може изазвати губитак података.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Програми спречавају одјављивање. Принудно одјављивање може изазвати губитак података.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Искључи</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Поново покрени</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Обустави</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Хибернација</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Одјави се</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Заиста желите да искључите?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Заиста желите да поново покренете?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Заиста желите да се одјавите?</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Закључај</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Промени корисника</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Промени систем</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <source>Wrong account</source>
        <translation>Погрешан налог</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Погрешна лозинка</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Закључаj екран</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Неуспешно закључавање екрана</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Време за верификацију отиска прста је истекло, унесите лозинку ручно</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Неподударање отиска прста</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Горе наведени корисници су и даље пријављени и њихови несачувани подаци ће нестати. Заиста желите да искључите?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Горе наведени корисници су и даље пријављени и њихови несачувани подаци ће нестати. Заиста желите да поново покренете?</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Искључи</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Поново покрени</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Обустави</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Хибернација</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Закључај</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Одјави се</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Промени корисника</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Промени систем</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Покрени праћење система</translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <source>Account</source>
        <translation>Налог</translation>
    </message>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Верификујте отисак прста</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Лозинка истиче за %n дан, промените је на време</numerusform><numerusform>Лозинка истиче за %n дана, промените је на време</numerusform><numerusform>Лозинка истиче за %n дан(а), промените је на време</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Лозинка је истекла, промените је</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Програми спречавају искључивање. Принудно искључивање може изазвати губитак података.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Да затворите програм, кликните на Откажи, затим затворите.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Програми спречавају поновно покретање. Принудно поновно покретање може изазвати губитак података.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Програми спречавају обуставу. Принудно обустављање може изазвати губитак података.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Програми спречавају хибернацију. Принудна хибернација може изазвати губитак података.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Програми спречавају одјављивање. Принудно одјављивање може изазвати губитак података.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Искључи</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Поново покрени</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Обустави</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Хибернација</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Одјави се</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Заиста желите да искључите?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Заиста желите да поново покренете?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Заиста желите да се одјавите?</translation>
    </message>
</context>
</TS>